@@ -33,7 +33,7 @@ extern zend_module_entry zip_module_entry;
 #define ZIP_OVERWRITE ZIP_TRUNCATE
 #endif
 
-#define PHP_ZIP_VERSION "1.19.3"
+#define PHP_ZIP_VERSION "1.19.4"
 
 /* {{{ ZIP_OPENBASEDIR_CHECKPATH(filename) */
 #define ZIP_OPENBASEDIR_CHECKPATH(filename) \
@@ -81,7 +81,7 @@ php_stream *php_stream_zip_opener(php_stream_wrapper *wrapper,       char *path,
 #else
 php_stream *php_stream_zip_opener(php_stream_wrapper *wrapper, const char *path, const char *mode, int options, char **opened_path, php_stream_context *context STREAMS_DC TSRMLS_DC);
 #endif
-php_stream *php_stream_zip_open(const char *filename, const char *path, const char *mode STREAMS_DC TSRMLS_DC);
+php_stream *php_stream_zip_open(struct zip *arch, const char *path, const char *mode STREAMS_DC TSRMLS_DC);
 
 extern php_stream_wrapper php_stream_zip_wrapper;
 
