@@ -2449,7 +2449,7 @@ PHP_METHOD(ZipArchive, setMtimeName)
 
 	if (zend_parse_parameters(ZEND_NUM_ARGS(), "sl|l",
 			&name, &name_len, &mtime,  &flags) == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
 
 	ZIP_FROM_OBJECT(intern, this);
@@ -2483,7 +2483,7 @@ PHP_METHOD(ZipArchive, setMtimeIndex)
 
 	if (zend_parse_parameters(ZEND_NUM_ARGS(), "ll|l",
 			&index, &mtime, &flags) == FAILURE) {
-		return;
+		RETURN_THROWS();
 	}
 
 	ZIP_FROM_OBJECT(intern, this);
@@ -2719,7 +2719,6 @@ PHP_METHOD(ZipArchive, extractTo)
 	zend_string *files_str = NULL;
 	HashTable *files_ht = NULL;
 
-	zval *zval_file = NULL;
 	php_stream_statbuf ssb;
 	char *pathto;
 	size_t pathto_len;
@@ -2756,7 +2755,8 @@ PHP_METHOD(ZipArchive, extractTo)
 			RETURN_FALSE;
 		}
 		for (i = 0; i < nelems; i++) {
-			if ((zval_file = zend_hash_index_find(files_ht, i)) != NULL) {
+			zval *zval_file;
+			if ((zval_file = zend_hash_index_find_deref(files_ht, i)) != NULL) {
 				switch (Z_TYPE_P(zval_file)) {
 					case IS_LONG:
 						break;
@@ -2878,7 +2878,6 @@ PHP_METHOD(ZipArchive, getStream)
 	char *mode = "rb";
 	zend_string *filename;
 	php_stream *stream;
-	ze_zip_object *obj;
 
 	if (zend_parse_parameters(ZEND_NUM_ARGS(), "P", &filename) == FAILURE) {
 		RETURN_THROWS();
@@ -2890,9 +2889,7 @@ PHP_METHOD(ZipArchive, getStream)
 		RETURN_FALSE;
 	}
 
-	obj = Z_ZIP_P(self);
-
-	stream = php_stream_zip_open(obj->filename, ZSTR_VAL(filename), mode STREAMS_CC);
+	stream = php_stream_zip_open(intern, ZSTR_VAL(filename), mode STREAMS_CC);
 	if (stream) {
 		php_stream_to_zval(stream, return_value);
 	} else {
